searchData={"items":[{"type":"module","title":"Domainr","doc":"HTTP Client for Domainr API.\n\nThis module provides functions to interact with the Domainr API, including\nsearching for domain names and checking their status.","ref":"Domainr.html"},{"type":"module","title":"Examples - Domainr","doc":"iex> Domainr.get!(\"/v2/status?domain=example.com\")\n    %{\"status\" => [...]}\n\n    iex> Domainr.get!(\"/v2/search?query=acme+cafe\")\n    %{\"results\" => [...]}","ref":"Domainr.html#module-examples"},{"type":"function","title":"Domainr.get!/1","doc":"Makes a GET request to the given URL and processes the response.","ref":"Domainr.html#get!/1"},{"type":"function","title":"Examples - Domainr.get!/1","doc":"iex> Domainr.get!(\"/v2/status?domain=example.com\")\n    %{\"status\" => [...]}\n\n    iex> Domainr.get!(\"/v2/search?query=acme+cafe\")\n    %{\"results\" => [...]}","ref":"Domainr.html#get!/1-examples"},{"type":"function","title":"Domainr.key/0","doc":"","ref":"Domainr.html#key/0"},{"type":"module","title":"Domainr.Register","doc":"Get registrar information for a given domain.\n\nThis module provides functions to get registrar information using the Domainr API.","ref":"Domainr.Register.html"},{"type":"module","title":"Examples - Domainr.Register","doc":"iex> Domainr.Register.get(\"google.com\")\n    %{\"registrar\" => [...]}\n\n    iex> Domainr.Register.get(\"example.com\")\n    %{\"redirect_url\" => \"https://iwantmyname.com/partner/search?r=domai.nr&u=303669&b=210737&q=example.com\"}","ref":"Domainr.Register.html#module-examples"},{"type":"function","title":"Domainr.Register.get/2","doc":"Get registrar information for a domain.","ref":"Domainr.Register.html#get/2"},{"type":"function","title":"Parameters - Domainr.Register.get/2","doc":"- `domain`: The domain to get registrar information for (required).\n  - `registrar`: The registrar to use for the request (optional).","ref":"Domainr.Register.html#get/2-parameters"},{"type":"function","title":"Examples - Domainr.Register.get/2","doc":"iex> Domainr.Register.get(\"google.com\")\n    %{\"registrar\" => [...]}\n\n    iex> Domainr.Register.get(\"example.com\", \"namecheap.com\")\n    %{\"redirect_url\" => \"https://iwantmyname.com/partner/search?r=domai.nr&u=303669&b=210737&q=example.com\"}","ref":"Domainr.Register.html#get/2-examples"},{"type":"module","title":"Domainr.Search","doc":"Domainr search function(s).\n\nThis module provides functions to search for domain names using the Domainr API.","ref":"Domainr.Search.html"},{"type":"module","title":"Examples - Domainr.Search","doc":"iex> Domainr.Search.find(\"acme+cafe\")\n    %{\"results\" => [...]}\n\n    iex> Domainr.Search.find(\"acme+cafe\", %Domainr.Search{location: \"de\", registrar: \"namecheap.com\", defaults: \"bike,cab\"})\n    %{\"results\" => [...]}\n\n    iex> Domainr.Search.locale_find(\"acme+cafe\", \"de\")\n    %{\"results\" => [...]}","ref":"Domainr.Search.html#module-examples"},{"type":"function","title":"Domainr.Search.find/1","doc":"Search for terms and get some domain suggestions.","ref":"Domainr.Search.html#find/1"},{"type":"function","title":"Parameters - Domainr.Search.find/1","doc":"- `terms`: The term(s) to search against (required).","ref":"Domainr.Search.html#find/1-parameters"},{"type":"function","title":"Examples - Domainr.Search.find/1","doc":"iex> Domainr.Search.find(\"acme+cafe\")\n    %{\"results\" => [...]}","ref":"Domainr.Search.html#find/1-examples"},{"type":"function","title":"Domainr.Search.find/2","doc":"Search for terms and get some domain suggestions with additional parameters.","ref":"Domainr.Search.html#find/2"},{"type":"function","title":"Parameters - Domainr.Search.find/2","doc":"- `terms`: The term(s) to search against (required).\n  - `search`: A `%Domainr.Search{}` struct with optional parameters.","ref":"Domainr.Search.html#find/2-parameters"},{"type":"function","title":"Examples - Domainr.Search.find/2","doc":"iex> Domainr.Search.find(\"acme+cafe\", %Domainr.Search{location: \"de\", registrar: \"namecheap.com\", defaults: \"bike,cab\"})\n    %{\"results\" => [...]}","ref":"Domainr.Search.html#find/2-examples"},{"type":"function","title":"Domainr.Search.locale_find/2","doc":"Search for terms and get some domain suggestions for a specific locale.","ref":"Domainr.Search.html#locale_find/2"},{"type":"function","title":"Parameters - Domainr.Search.locale_find/2","doc":"- `terms`: The term(s) to search against (required).\n  - `locale`: The locale to search in (required).","ref":"Domainr.Search.html#locale_find/2-parameters"},{"type":"function","title":"Examples - Domainr.Search.locale_find/2","doc":"iex> Domainr.Search.locale_find(\"acme+cafe\", \"de\")\n    %{\"results\" => [...]}","ref":"Domainr.Search.html#locale_find/2-examples"},{"type":"module","title":"Domainr.Status","doc":"Search the status for (a) given domain(s).\n\nThis module provides functions to check the status of domain names using the Domainr API.","ref":"Domainr.Status.html"},{"type":"module","title":"Examples - Domainr.Status","doc":"iex> Domainr.Status.get(\"google.com,google.de\")\n    %{\"status\" => [...]}\n\n    iex> Domainr.Status.find_free_tlds_for(\"google\", [\".com\", \".de\"])\n    %{\"status\" => [...]}","ref":"Domainr.Status.html#module-examples"},{"type":"function","title":"Domainr.Status.find_free_tlds_for/2","doc":"Search free TLDs for a given domain.","ref":"Domainr.Status.html#find_free_tlds_for/2"},{"type":"function","title":"Parameters - Domainr.Status.find_free_tlds_for/2","doc":"- `domain`: The domain to check for free TLDs (required).\n  - `list`: A list of TLDs to check (required).","ref":"Domainr.Status.html#find_free_tlds_for/2-parameters"},{"type":"function","title":"Examples - Domainr.Status.find_free_tlds_for/2","doc":"iex> Domainr.Status.find_free_tlds_for(\"google\", [\".com\", \".de\"])\n    %{\"status\" => [...]}","ref":"Domainr.Status.html#find_free_tlds_for/2-examples"},{"type":"function","title":"Domainr.Status.get/1","doc":"Get the status for a string with domains.","ref":"Domainr.Status.html#get/1"},{"type":"function","title":"Parameters - Domainr.Status.get/1","doc":"- `domains`: A comma-separated string of domains to check the status for (required).","ref":"Domainr.Status.html#get/1-parameters"},{"type":"function","title":"Examples - Domainr.Status.get/1","doc":"iex> Domainr.Status.get(\"google.com,google.de\")\n    %{\"status\" => [...]}","ref":"Domainr.Status.html#get/1-examples"},{"type":"extras","title":"Domainr","doc":"# Domainr\n\n  Domainr is a [Domainr wrapper for](https://domainr.build) in Elixir\n  making it easy to search and find (available) domains and TLDs.","ref":"readme.html"},{"type":"extras","title":"Installation - Domainr","doc":"1. Add Domainr to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [{:domainr, \"~> 0.0.2\"}]\nend\n```\n2. Ensure Domainr is started before your application:\n\n```elixir\ndef application do\n  [mod: {Domainr, []}]\nend\n```\n\n3. Add your API key from RAPIDAPI or Domainr\n\nFor RapidAPI (free or non-commercial use):\n```sh\nexport RAPIDAPI_KEY=\"YOUR_API_KEY\"\n```\n\n_or_\n\nFor high-volume, commercial use:\n```sh\nexport DOMAINR_API_KEY=\"YOUR_API_KEY\"\n```\nand set 4. as it is no longer optional.\n\n\n4. (Optional) Set the base URL for the API:\n\nhttps://api.domainr.com (high-volume, commercial use)\nhttps://domainr.p.rapidapi.com (free or non-commercial use)\n\n```elixir\nconfig :domainr, base_url: \"https://api.domainr.com\"\n\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Domainr","doc":"Do easily find the status for one or more domains:\n\n```elixir\nDomainr.Status.get(\"google.com,domainr.build\")\n```\n\nYou have a domain name in mind and want to check for the available TLDs?\n\n```elixir\nDomainr.Status.find_free_tlds_for(\"awesomename\", [\".com\",\".io\"])\n```\n\nYou need some suggestions for domain names?\n\n```elixir\nDomainr.Search.find(\"green+coffee\")\n```\n\n# You want to be more specific in your search?\n\nBe more local (here for germany):\n\n```elixir\nDomainr.Search.find(\"gruener+kaffee\", %Domainr.Search{location: \"de\"})\n# Shortcut\nDomainr.Search.locale_find(\"gruener+kaffee\", \"de\")\n```\n\nYou have some TLDs in mind?\n\n```elixir\n    Domainr.Search.find(\"green+coffee\", %Domainr.Search{defaults: \"coffee,club\"})\n```\n\nYou want to get registrar information for a domain?\n\n```elixir\nDomainr.Register.get(\"example.com\")\n```","ref":"readme.html#usage"},{"type":"extras","title":"Authorship and License - Domainr","doc":"","ref":"readme.html#authorship-and-license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}